]> git.cryptolib.org Git - avr-crypto-lib.git/blobdiff - A5_1.c
small fix
[avr-crypto-lib.git] / A5_1.c
diff --git a/A5_1.c b/A5_1.c
index ff1bb9606e816ebfd4bd4aa09973ad9183a6f229..a07b4846483381d15cd224b07098aa371096017c 100644 (file)
--- a/A5_1.c
+++ b/A5_1.c
@@ -1,8 +1,27 @@
+/* A5_1.c */
+/*
+    This file is part of the AVR-Crypto-Lib.
+    Copyright (C) 2008  Daniel Otte (daniel.otte@rub.de)
+
+    This program is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*/
 /* 
* File:               A5_1.c
* Author:     Daniel Otte
* Date:       24.06.2006
* License: GPL
  * Description: Implementation of the A5/1 stream cipher algorithm, as used in GSM.
  * ! Warning, this is weak crypto !
  * 
@@ -17,7 +36,7 @@ uint8_t a5_1_clock_core(a5_1_ctx_t *c, uint8_t clockoverride);
 
 
 /*
- * length is length of key in bytes!
+ * length is length of key in bits!
  */
 
 void a5_1_init(a5_1_ctx_t *c, void* key, uint8_t keylength_b, void* iv, uint8_t ivlength_b){
@@ -1,8 +1,27 @@
 /* 
- * File:               A5_1.c
- * Author:     Daniel Otte
- * Date:       24.06.2006
- * License: GPL
+ * File:        A5_1.c
+ * Author:      Daniel Otte
+ * email:       daniel.otte@rub.de
+ * Date:        2006-06-24
+ * License:     GPLv3 or later
  * Description: Implementation of the A5/1 stream cipher algorithm, as used in GSM.
  * ! Warning, this is weak crypto !